==> wheezy.core-0.1.152.tar.gz: wheezy.core-0.1.152/README.md <==
# wheezy.core

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.core.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.core)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.core/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.core?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezycore/badge/?version=latest)](https://wheezycore.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.core.svg)](https://badge.fury.io/py/wheezy.core)

[wheezy.core](https://pypi.org/project/wheezy.core) is a
[python](http://www.python.org) package written in pure Python code. It
provides core features.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.core),
  [examples](https://github.com/akornatskyy/wheezy.core/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.core/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.core)
- [documentation](https://wheezycore.readthedocs.io/en/latest/)

## Install

[wheezy.core](https://pypi.org/project/wheezy.core) requires
[python](http://www.python.org) version 2.4 to 2.7 or 3.2+. It is
independent of operating system. You can install it from
[pypi](https://pypi.org/project/wheezy.core) site:

```sh
pip install -U wheezy.core
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.core).

==> wheezy.core-3.0.1.tar.gz: wheezy.core-3.0.1/README.md <==
# wheezy.core

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.core.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.core)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.core/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.core?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezycore/badge/?version=latest)](https://wheezycore.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.core.svg)](https://badge.fury.io/py/wheezy.core)

[wheezy.core](https://pypi.org/project/wheezy.core) is a
[python](http://www.python.org) package written in pure Python code. It
provides core features.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.core),
  [examples](https://github.com/akornatskyy/wheezy.core/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.core/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.core)
- [documentation](https://wheezycore.readthedocs.io/en/latest/)

## Install

[wheezy.core](https://pypi.org/project/wheezy.core) requires
[python](http://www.python.org) version 3.6+. It is independent of operating
system. You can install it from [pypi](https://pypi.org/project/wheezy.core)
site:

```sh
pip install -U wheezy.core
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.core).
